@@ -1,3 +1,32 @@
+
+=encoding utf-8
+
+=head1 NAME
+
+Graph::Undirected::Hamiltonicity - decide whether a given Graph::Undirected
+    contains a Hamiltonian Cycle.
+
+=head1 VERSION
+
+Version 0.14
+
+=head1 LICENSE
+
+Copyright (C) Ashwin Dixit.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Ashwin Dixit, C<< <ashwin at CPAN dot org> >>
+
+=cut
+
+
+use Modern::Perl;
+use lib 'local/lib/perl5';
+
 package Graph::Undirected::Hamiltonicity;
 
 # ABSTRACT: decide whether a given Graph::Undirected contains a Hamiltonian Cycle.
@@ -5,15 +34,13 @@ package Graph::Undirected::Hamiltonicity;
 # You can get documentation for this module with this command:
 #    perldoc Graph::Undirected::Hamiltonicity
 
-use Modern::Perl;
-
 use Graph::Undirected::Hamiltonicity::Output qw(&output);
 use Graph::Undirected::Hamiltonicity::Tests qw(:all);
 use Graph::Undirected::Hamiltonicity::Transforms qw(:all);
 
 use Exporter qw(import);
 
-our $VERSION     = '0.01';
+our $VERSION     = '0.14';
 our @EXPORT      = qw(graph_is_hamiltonian);    # exported by default
 our @EXPORT_OK   = qw(graph_is_hamiltonian);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
